@@ -17,6 +17,8 @@ let make n =
 external order : t -> int
     = "ml_gsl_cheb_order"
 
+external coefs : t -> float array = "ml_gsl_cheb_coefs"
+
 external init : t -> Gsl_fun.gsl_fun -> a:float -> b:float -> unit
     = "ml_gsl_cheb_init"
 
@@ -32,27 +34,15 @@ external _eval_n : t -> int -> float -> float
 external _eval_n_err : t -> int -> float -> Gsl_fun.result
     = "ml_gsl_cheb_eval_n_err"
 
-external _eval_mode : t -> float -> Gsl_fun.mode -> float
-    = "ml_gsl_cheb_eval_mode"
+let eval cs ?order x =
+  match order with
+  | None -> _eval cs x
+  | Some o -> _eval_n cs o x
 
-external _eval_mode_e : t -> float -> Gsl_fun.mode -> Gsl_fun.result
-    = "ml_gsl_cheb_eval_mode_e"
-
-let eval cs ?mode ?order x =
-  match mode with
-  | Some m -> _eval_mode cs x m
-  | None -> 
-      match order with
-      | None -> _eval cs x
-      | Some o -> _eval_n cs o x
-
-let eval_err cs ?mode ?order x =
-  match mode with
-  | Some m -> _eval_mode_e cs x m
-  | None -> 
-      match order with
-      | None -> _eval_err cs x
-      | Some o -> _eval_n_err cs o x
+let eval_err cs ?order x =
+  match order with
+  | None -> _eval_err cs x
+  | Some o -> _eval_n_err cs o x
 
 external calc_deriv : t -> t -> unit
     = "ml_gsl_cheb_calc_deriv"
