@@ -5,11 +5,14 @@
 open Gsl_vectmat
 
 type symm_ws
-
 external _symm_alloc : int -> symm_ws
     = "ml_gsl_eigen_symm_alloc"
 external _symm_free : symm_ws -> unit
     = "ml_gsl_eigen_symm_free"
+let make_symm_ws s =
+  let ws = _symm_alloc s in
+  Gc.finalise _symm_free ws ;
+  ws
 
 external _symm : mat -> vec -> symm_ws -> unit
     = "ml_gsl_eigen_symm"
@@ -19,7 +22,10 @@ let symm ?protect a =
   let (n, _) = Gsl_vectmat.dims a' in
   let v = Gsl_vector.create n in
   let ws = _symm_alloc n in
-  _symm a' (`V v) ws ;
+  begin
+    try _symm a' (`V v) ws 
+    with exn -> _symm_free ws ; raise exn
+  end ;
   _symm_free ws ;
   v
 
@@ -28,6 +34,10 @@ external _symmv_alloc_v : int -> symmv_ws
     = "ml_gsl_eigen_symmv_alloc"
 external _symmv_free_v : symmv_ws -> unit
     = "ml_gsl_eigen_symmv_free"
+let make_symmv_ws s =
+  let ws = _symmv_alloc_v s in
+  Gc.finalise _symmv_free_v ws ;
+  ws
 
 external _symmv : mat -> vec -> mat -> symmv_ws -> unit
     = "ml_gsl_eigen_symmv"
@@ -38,7 +48,10 @@ let symmv ?protect a =
   let v = Gsl_vector.create n in
   let evec = Gsl_matrix.create n n in
   let ws = _symmv_alloc_v n in
-  _symmv a' (`V v) (`M evec) ws ;
+  begin
+    try _symmv a' (`V v) (`M evec) ws 
+    with exn -> _symmv_free_v ws ; raise exn
+  end ;
   _symmv_free_v ws ;
   (v, evec)
 
@@ -53,12 +66,16 @@ external symmv_sort : Gsl_vector.vector * Gsl_matrix.matrix -> sort -> unit    =
 
 
 (* Complex Hermitian Matrices *)
-type herm_ws
 
+type herm_ws
 external _herm_alloc : int -> herm_ws
     = "ml_gsl_eigen_herm_alloc"
 external _herm_free : herm_ws -> unit
     = "ml_gsl_eigen_herm_free"
+let make_herm_ws s =
+  let ws = _herm_alloc s in
+  Gc.finalise _herm_free ws ;
+  ws
 
 external _herm : cmat -> vec -> herm_ws -> unit
     = "ml_gsl_eigen_herm"
@@ -68,7 +85,10 @@ let herm ?protect a =
   let (n, _) = Gsl_vectmat.dims a' in
   let v = Gsl_vector.create n in
   let ws = _herm_alloc n in
-  _herm a' (`V v) ws ;
+  begin
+    try  _herm a' (`V v) ws
+    with exn -> _herm_free ws ; raise exn
+  end ;
   _herm_free ws ;
   v
 
@@ -77,6 +97,10 @@ external _hermv_alloc_v : int -> hermv_ws
     = "ml_gsl_eigen_hermv_alloc"
 external _hermv_free_v : hermv_ws -> unit
     = "ml_gsl_eigen_hermv_free"
+let make_hermv_ws s =
+  let ws = _hermv_alloc_v s in
+  Gc.finalise _hermv_free_v ws ;
+  ws
 
 external _hermv : cmat -> vec -> cmat -> hermv_ws -> unit
     = "ml_gsl_eigen_hermv"
@@ -87,9 +111,11 @@ let hermv ?protect a =
   let v = Gsl_vector.create n in
   let evec = Gsl_matrix_complex.create n n in
   let ws = _hermv_alloc_v n in
-  _hermv a' (`V v) (`CM evec) ws ;
+  begin
+    try _hermv a' (`V v) (`CM evec) ws
+    with exn -> _hermv_free_v ws ; raise exn
+  end ;
   _hermv_free_v ws ;
   (v, evec)
 
 external hermv_sort : Gsl_vector.vector * Gsl_matrix_complex.matrix -> sort -> unit    = "ml_gsl_eigen_hermv_sort"
-
