@@ -2,14 +2,12 @@
 (* Copyright (©) 2002-2005 - Olivier Andrieu                *)
 (* distributed under the terms of the GPL version 2         *)
 
+(** Eigensystems *)
+
 open Gsl_vectmat
 
 type symm_ws
-
-external _symm_alloc : int -> symm_ws
-    = "ml_gsl_eigen_symm_alloc"
-external _symm_free : symm_ws -> unit
-    = "ml_gsl_eigen_symm_free"
+val make_symm_ws : int -> symm_ws
 
 external _symm : mat -> vec -> symm_ws -> unit
     = "ml_gsl_eigen_symm"
@@ -23,10 +21,7 @@ val symm :
   Gsl_vector.vector
 
 type symmv_ws
-external _symmv_alloc_v : int -> symmv_ws
-    = "ml_gsl_eigen_symmv_alloc"
-external _symmv_free_v : symmv_ws -> unit
-    = "ml_gsl_eigen_symmv_free"
+val make_symmv_ws : int -> symmv_ws
 
 external _symmv : mat -> vec -> mat -> symmv_ws -> unit
     = "ml_gsl_eigen_symmv"
@@ -51,11 +46,7 @@ external symmv_sort : Gsl_vector.vector * Gsl_matrix.matrix -> sort -> unit
 
 
 type herm_ws
-
-external _herm_alloc : int -> herm_ws
-    = "ml_gsl_eigen_herm_alloc"
-external _herm_free : herm_ws -> unit
-    = "ml_gsl_eigen_herm_free"
+val make_herm_ws : int -> herm_ws
 
 external _herm : cmat -> vec -> herm_ws -> unit
     = "ml_gsl_eigen_herm"
@@ -68,10 +59,7 @@ val herm :
   Gsl_vector.vector
 
 type hermv_ws
-external _hermv_alloc_v : int -> hermv_ws
-    = "ml_gsl_eigen_hermv_alloc"
-external _hermv_free_v : hermv_ws -> unit
-    = "ml_gsl_eigen_hermv_free"
+val make_hermv_ws : int -> hermv_ws
 
 external _hermv : cmat -> vec -> cmat -> hermv_ws -> unit
     = "ml_gsl_eigen_hermv"
@@ -87,4 +75,3 @@ external hermv_sort :
   Gsl_vector.vector * Gsl_matrix_complex.matrix -> 
     sort -> unit
     = "ml_gsl_eigen_hermv_sort"
-
