@@ -2,11 +2,14 @@
 (* Copyright (©) 2002-2005 - Olivier Andrieu                *)
 (* distributed under the terms of the GPL version 2         *)
 
+(** Random Number Distributions *)
 
 external gaussian : Gsl_rng.t -> sigma:float -> float 
     = "ml_gsl_ran_gaussian"
 external gaussian_ratio_method : Gsl_rng.t -> sigma:float -> float
   = "ml_gsl_ran_gaussian_ratio_method"
+external gaussian_ziggurat : Gsl_rng.t -> sigma:float -> float 
+    = "ml_gsl_ran_gaussian_ziggurat"
 external gaussian_pdf : float -> sigma:float -> float
   = "ml_gsl_ran_gaussian_pdf" "gsl_ran_gaussian_pdf" "float"
 
@@ -91,8 +94,12 @@ external levy_skew :
 
 external gamma : Gsl_rng.t -> a:float -> b:float -> float
   = "ml_gsl_ran_gamma"
+external gamma_int : Gsl_rng.t -> a:int -> float 
+    = "ml_gsl_ran_gamma_int"
 external gamma_pdf : float -> a:float -> b:float -> float
   = "ml_gsl_ran_gamma_pdf" "gsl_ran_gamma_pdf" "float"
+external gamma_mt : Gsl_rng.t -> a:int ->  b:float -> float
+    = "ml_gsl_ran_gamma_mt"
 
 
 external flat : Gsl_rng.t -> a:float -> b:float -> float
@@ -199,6 +206,10 @@ external bernoulli_pdf : int -> p:float -> float
 
 external binomial : Gsl_rng.t -> p:float -> n:int -> int
   = "ml_gsl_ran_binomial"
+external binomial_knuth : Gsl_rng.t -> p:float -> n:int -> int
+  = "ml_gsl_ran_binomial_knuth"
+external binomial_tpe : Gsl_rng.t -> p:float -> n:int -> int
+  = "ml_gsl_ran_binomial_tpe"
 external binomial_pdf : int -> p:float -> n:int -> float
   = "ml_gsl_ran_binomial_pdf"
 
@@ -209,9 +220,9 @@ external multinomial_pdf : p:float array -> n:int array -> float
 external multinomial_lnpdf : p:float array -> n:int array -> float
     = "ml_gsl_ran_multinomial_lnpdf"
 
-external negative_binomial : Gsl_rng.t -> p:float -> n:float -> int
+external negative_binomial : Gsl_rng.t -> p:float -> n:int -> int
   = "ml_gsl_ran_negative_binomial"
-external negative_binomial_pdf : int -> p:float -> n:float -> float
+external negative_binomial_pdf : int -> p:float -> n:int -> float
   = "ml_gsl_ran_negative_binomial_pdf"
 
 
