@@ -13,6 +13,7 @@
 /* GAUSSIAN */
 ML2(gsl_ran_gaussian, Rng_val, Double_val, copy_double)
 ML2(gsl_ran_gaussian_ratio_method, Rng_val, Double_val, copy_double)
+ML2(gsl_ran_gaussian_ziggurat, Rng_val, Double_val, copy_double)
 ML2(gsl_ran_gaussian_pdf, Double_val, Double_val, copy_double)
 
 ML1(gsl_ran_ugaussian, Rng_val, copy_double)
@@ -77,7 +78,9 @@ ML4(gsl_ran_levy_skew, Rng_val, Double_val, Double_val, Double_val, copy_double)
 
 /* GAMMA */
 ML3(gsl_ran_gamma, Rng_val, Double_val, Double_val, copy_double)
+ML2(gsl_ran_gamma_int, Rng_val, Unsigned_int_val, copy_double)
 ML3(gsl_ran_gamma_pdf, Double_val, Double_val, Double_val, copy_double)
+ML3(gsl_ran_gamma_mt, Rng_val, Double_val, Double_val, copy_double)
 
 /* FLAT */
 ML3(gsl_ran_flat, Rng_val, Double_val, Double_val, copy_double)
@@ -202,6 +205,7 @@ ML2(gsl_ran_bernoulli_pdf, Int_val, Double_val, copy_double)
 
 /* BINOMIAL */
 ML3(gsl_ran_binomial, Rng_val, Double_val, Int_val, Val_int)
+ML3(gsl_ran_binomial_knuth, Rng_val, Double_val, Int_val, Val_int)
 ML3(gsl_ran_binomial_tpe, Rng_val, Double_val, Int_val, Val_int)
 ML3(gsl_ran_binomial_pdf, Int_val, Double_val, Int_val, copy_double)
 
