@@ -456,19 +456,7 @@ ml_gsl_sf_legendre_sphPlm_array(value lmax, value m,
                                Double_array_val(result_array));
   return Val_unit;
 }
-
-CAMLprim value
-ml_gsl_sf_legendre_array_size(value lmax, value m)
-{
-  CAMLparam2(lmax, m);
-  CAMLlocal1(ret);
-  int gsl_ret;
-
-  gsl_ret = gsl_sf_legendre_array_size(Int_val(lmax), Int_val(m));
-  
-  ret = Val_int(gsl_ret);
-  CAMLreturn(ret);
-}
+ML2(gsl_sf_legendre_array_size, Int_val, Int_val, Val_int)
 
 /* LOGARITHM and related functions */
 SF1(log, Double_val)
